import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * This   demo  displays  a  vertical  chart  with a  right  scale  enabled.
 * It also demonstrates how to set the position of the left and right scales 
 * along the vertical axis.
 * There are  two scrolling  bars, placed to the left and right  side of the 
 * frame, that dynamically adjust the extension of both scales  if automatic 
 * scale positioning is disabled.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener,AdjustmentListener {
    
    JCheckBox is3D;
    JComboBox shiftScope;
    Graph graph;
    JScrollBar sb1,sb2;
    JCheckBox autoScalePos;
    
    GraphSet primaryGraphSet,secondaryGraphSet;
    
    public Main()  {
	
        addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
	
        setTitle("The JetChart Library - Double Axis Demo");
	
        is3D = new JCheckBox("3D",true);
        is3D.addItemListener(this);
	
	autoScalePos=new JCheckBox("Automatic scale positioning",true);
	autoScalePos.addItemListener(this);
	
        String[] items={"GraphSet","Graph"};
        shiftScope=new JComboBox(items);
        shiftScope.setSelectedIndex(1);
        shiftScope.addItemListener(this);
	
        sb1=new JScrollBar(Scrollbar.VERTICAL,100,1,0,101);
        sb1.addAdjustmentListener(this);
        sb1.setEnabled(false);
        sb2=new JScrollBar(Scrollbar.VERTICAL,0,1,0,101);
        sb2.addAdjustmentListener(this);
        sb2.setEnabled(false);
	
        JPanel panel = new JPanel(new FlowLayout(0));
        panel.add(is3D);
	panel.add(autoScalePos);
        panel.add(new JLabel("Bar series shift scope:",JLabel.RIGHT));
        panel.add(shiftScope);
	
        Container ct=getContentPane();

        ct.add("North", panel);
	
        ct.add("West",sb1);
        ct.add("East",sb2);
	
        // Creates the chart context, setting the chart title.
        graph = new Graph();
	
	// Enables automatic scale positioning.
	graph.setAutoScalePositioningEnabled(true);
	
        graph.setTitle(new String[]{"The JetChart Library","Double axis demo" });
	graph.setTitleFont(new Font("Monospaced",Font.PLAIN,12));
	
	// Sets left title properties
	graph.getLeftTitle().setText("Left title");
	graph.getLeftTitle().setFont(new Font("Monospaced",Font.PLAIN,20));
	graph.getLeftTitle().setForeground(Color.blue);
	
	// Sets right title properties
	graph.getRightTitle().setText("Right title");
	graph.getRightTitle().setFont(new Font("Monospaced",Font.PLAIN,20));
	graph.getRightTitle().setForeground(Color.red);

        // Disables inline arrangement of  3D series.
        graph.set3DSeriesInLineEnabled(false);
	
        graph.set3DEnabled(true);
	
        graph.getToolTip().setEnabled(true);
	
        // Sets the format of values displayed along the scales and in the tooltips.
        graph.setValueFormat("#,##0.00");
	
	// Configures the primary GraphSet object. Take a look at the GraphSet class
	// documentation for further details.
	configPrimaryGraphSet();
	
	// Creates a secondary graph set and sets its properties.
	createSecondaryGraphSet();
	
	// Sets the labels.
        graph.setLabels(new String[]{ "Jan\n2001", "Feb\n2001", "Mar\n2001", "Apr\n2001", "May\n2001", 
				      "Jun\n2001", "Jul\n2001", "Aug\n2001", "Sep\n2001", "Oct\n2001" });
	
        // Creates a bar series.
        BarSerie barSerie1=new BarSerie(new double[]{3232.23,2555.67,4543.12,5233.55,6212.11,3423.11,
						     2657.15,3777.81,5657.90,4876.37},"Bar series 1");
        barSerie1.setColor(Color.red);
	
	// Creates another bar series to be added to a secondary GraphSet.
        BarSerie barSerie2 = new BarSerie(new double[]{ 123.22, 145.65, 98.71, 75.44, 88.12, 110.91, 
							154.33, 170.81, 149.02, 120.0 }, "Bar series 2");
        barSerie2.setColor(Color.green);
	
	// Includes the bar series in the secondary graph set. The bar series data points are painted
	// within the scale of the secondary graph set, which is positioned on the right axis.
	secondaryGraphSet.addSerie(barSerie2);
	
	// Adds the series to the chart context.
        graph.addSerie(barSerie1);
        graph.addSerie(barSerie2);
	
        // Sets the shift scope of bar series to GRAPH_SCOPE. See the Graph class API for
        // further information concerning this method. There is  a list box at the top of
        // the window that toggles the shift scope between GRAPH_SCOPE and GRAPHSET_SCOPE,
        // to demonstrate the effect caused by changing the shift scope.
        graph.setShiftScope(Graph.GRAPH_SCOPE);
	
	// Adds the secondary GraphSet object to the chart context. 
	graph.addGraphSet(secondaryGraphSet);
	
        ct.add("Center", graph);
        setSize(600, 550);
        setVisible(true);
    }
    
    private void configPrimaryGraphSet() {
	
	// Gets a reference to the Scale object of the primary GraphSet.
	primaryGraphSet=graph.getGraphSet(0);
	Scale scale=primaryGraphSet.getScale();
	
	// Sets the scale color to red.
	scale.setColor(Color.red);
	
	// Disables the left scale automatic range and sets the maximum and increment values.
	scale.setAutoScaleEnabled(false);
	scale.setMaxValue(10000);
	scale.setIncrement(1500);
	
	// Enables the primary graph set grid and the colored bands.
	Grid grid=primaryGraphSet.getGrid();
	grid.setEnabled(true);
	grid.setColoredBandsEnabled(true);
	
	
	
    }
    
    private void createSecondaryGraphSet() {
	
	// Gets a reference to the Scale object of the secondary GraphSet.
	secondaryGraphSet=new GraphSet();
	Scale scale=secondaryGraphSet.getScale();
	
	// Sets the scale color to green.
	scale.setColor(Color.green.darker());
	
	// Moves the scale to the right axis.
	scale.setPosition(Scale.RIGHT);
	
        // Enables the secondary graph set grid and sets its color.
	Grid grid=secondaryGraphSet.getGrid();
	grid.setEnabled(true);
	grid.setColor(Color.lightGray);
	
    }
    
    public void adjustmentValueChanged(AdjustmentEvent evt) {
	
	// Adjusts the left scale end point.
	if (evt.getSource()==sb1) 
	    adjustLeftScale();
	
	// Adjusts the right scale start point.
	else if (evt.getSource()==sb2) 
	    adjustRightScale();
	
	graph.refresh();
	
    }
    
    private void adjustLeftScale() {
	float value=sb1.getValue();
	value/=100;
	Scale scale=graph.getGraphSet(0).getScale();
	scale.setStartPoint(0);
	scale.setEndPoint(value);
	
    }
    
    private void adjustRightScale() {
	float value=sb2.getValue();
	value/=100;
	Scale scale=graph.getGraphSet(1).getScale();
	scale.setStartPoint(value);
	scale.setEndPoint(1);
	
    }
    
    public void itemStateChanged(ItemEvent evt) {
	
	if (evt.getSource()==is3D) {
	    // Enables/disables 3D effect.
	    graph.set3DEnabled(is3D.isSelected());
	}
        else if (evt.getSource()==autoScalePos){ 
            sb1.setEnabled(!autoScalePos.isSelected());
            sb2.setEnabled(!autoScalePos.isSelected());
	    // Enables/disables automatic scale positioning.
	    graph.setAutoScalePositioningEnabled(autoScalePos.isSelected());
	    if (autoScalePos.isSelected()==false) {
		adjustLeftScale();
		adjustRightScale();
		
	    }
        }
        else if (evt.getSource()==shiftScope) {
	    int index=shiftScope.getSelectedIndex();
	    graph.setShiftScope(index);
        }
	graph.repaint();
	
    }
    
  
    public static void main(String astring[])     {
        new Main();
    }
    
}
