import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * This application displays two bar series plotted against different scales
 * placed along the left and right vertical axis. Different from the example
 * found in the 'example1' folder,  both  scales start  and  end  points are 
 * exactly the same.
 */
public class Main extends JFrame {

    Graph graph;

    public Main() {

	setTitle("The JetChart Library - Double Axis Demo");

	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
	
	

	graph=new Graph();

	graph.setLabels(new String[]{"l1","l2","l3","l4","l5","l6"});

	// This method must be passed GRAPH_SCOPE if bar series belonging to 
	// different GraphSet objects have to be displayed side by side.
	graph.setShiftScope(Graph.GRAPH_SCOPE);
	graph.getToolTip().setEnabled(true);
	double[] values1={50000,80000,70000,30000,50000,90000};
	double[] values2={.33,.44,.56,.13,.78,.80};


	// Creates two bar series.
	BarSerie bs1=new BarSerie();
	BarSerie bs2=new BarSerie();
	bs1.setColor(Color.red);
	bs2.setColor(Color.green.darker());
	bs1.setValues(values1);
	bs2.setValues(values2);
	bs1.setTitle("Volume");
	bs2.setTitle("Percentage");

	// Sets the value format of each series. Values are formatted to be displayed
	// in data points legends and tooltips.
	bs1.setValueFormat("#,##0.00");
	bs2.setValueFormat("#%");
	
	graph.addSerie(bs1);
	graph.addSerie(bs2);

	// Sets the properties of the scale of the primary GraphSet object.
	GraphSet primaryGraphSet=graph.getGraphSet(0);
	Scale scale=primaryGraphSet.getScale();
	scale.setAutoScaleEnabled(false);
	scale.setMaxValue(100000);
	scale.setIncrement(10000);
	scale.setColor(Color.red);
	scale.setValueFormat("US$ ###,##0.00");

	// Enables the Grid of the primary GraphSet object.
	Grid grid=primaryGraphSet.getGrid();
	grid.setEnabled(true);
	grid.setColoredBandsEnabled(true);

	// Creates a secondary GraphSet object and sets the properties of its scale.
	GraphSet graphSet=new GraphSet();
	scale=graphSet.getScale();
	scale.setPosition(Scale.RIGHT);
	scale.setAutoScaleEnabled(false);
	scale.setMaxValue(1);
	scale.setIncrement(.1);
	scale.setColor(Color.green.darker());
	scale.setValueFormat("### %");
	
	// Enables the grid of the secondary GraphSet.
	grid=graphSet.getGrid();
	grid.setEnabled(true);
	grid.setColor(Color.gray);

	// Adds the second bar series to the secondary GraphSet object.
	graphSet.addSerie(bs2);

	// Adds the GraphSet to the chart context.
	graph.addGraphSet(graphSet);

	// Sets the left and right titles.
	LeftTitle lt=graph.getLeftTitle();
	lt.setText("Volume");
	lt.setFont(new Font("SansSerif",Font.PLAIN,12));

	RightTitle rt=graph.getRightTitle();
	rt.setText("Percentage");
	rt.setFont(new Font("SansSerif",Font.PLAIN,12));

	// Sets the chart title
	graph.setTitle(new String[]{"The JetChart Library","Double Axis Demo"});
	graph.setTitleFont(new Font("SansSerif",Font.BOLD,12));

	graph.setBackground(new Color(255,255,204));

        Container ct=getContentPane();

	ct.add("Center",graph);
	
	setSize(600,400);

	setVisible(true);
	
    }
    
    public static void main(String[] args) {
	new Main();
    }
}
