/**
 * This example  demonstrates  the generation  of a gif encoded image  using JetChart and 
 * the Pure Java Awt Toolkit(PJA). The advantage  of  working  with PJA is that offscreen
 * applications, like servlets, can generate chart images with  an  image encoder without
 * the need of a valid display, as required  in Unix systems  like   Linux, Solaris, etc.
 * Read the readme.txt file located in this application directory for further information.
 *
 * Use  the  heavyweight  version  of  JetChart to run this application, adding the files
 * GraphChart.jar and Encoders.jar to  your system classpath. These files can be found in
 * the JetChart/lib/AWT directory.
 *
 * The Pure Java Awt Toolkit(PJA) is copyright   2000-2002 Emmanuel PUYBARET / eTeks 
 * info@eteks.com. All Rights Reserved.
 * Visit eTeks web site for up-to-date versions of PJA and other Java tools and tutorials : 
 * http://www.eteks.com/
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */

import java.awt.*;
import javax.swing.*;
import java.io.*;
import com.jinsight.jetchart.*;

import java.awt.image.BufferedImage; 
import java.util.Locale;

public class Main {

    Graph graph;
    AreaSerie as;

    public Main() {

	graph=new Graph();

	// Sets graphic context properties
	setChartProperties();

	// Creates an area series and sets its properties
	createSerie();
	
	// Adds a series to the graphic context
	graph.addSerie(as);

	// Creates a ChartEncoder object.
	ChartEncoder ce=new ChartEncoder(graph);

	// Sets the chart size and enables offscreen image generation
	graph.setOffScreenGraphEnabled(true);
	graph.setSize(500,400);

	// The ChartEncoder class creates an invisible Frame object which
	// is used to lay out the Graph instance and to create an offscreen
	// image with the Component.createImage(int width,int height) 
	// method. After the end of the encoding process, a call to the 
	// method Frame.dispose() is placed, and if the AWT toolkit is
	// replaced by the PJA toollkit, the application hangs at this point,
	// and the chart image is not encoded.
	// To prevent this problem we must enable the generation of offscreen
	// images using the BufferedImage class, passing true to the method
	// below. 
	graph.setBufferedImageEnabled(true,BufferedImage.TYPE_INT_ARGB);

	// When the ChartEncoder class creates the Frame, the Graph object
	// is laid out on it, and the locale information is retrieved from
	// the parent container. If the BufferedImage is used to generate an
	// offscreen image, the Frame creation is bypassed and consequently
	// the Graph object cannot get the locale information. So, we have
	// to explicitly set the locale, otherwise an exception is raised.
	graph.setLocale(Locale.getDefault());

	// Generates a gif file using the GifEncoder class.
	try {
	    File file=new File("chart.gif");
	    FileOutputStream out=new FileOutputStream(file);
	    
	    // Gif encodes the chart image.
	    ce.gifEncode(out);

	}
	catch (IOException e) {
	    e.printStackTrace();
	}
    }
     
    private void setChartProperties() {

	graph.setTitle(new String[]{"The  JetChart  Library",
				    "Offscreen generation of an area chart",
				    "with the Pure Java AWT Toolkit(PJA)"});
	graph.getLegend().setFont(new Font("SansSerif",Font.ITALIC,12));
	graph.setTitleFont(new Font("SansSerif",Font.PLAIN,12));
	graph.setLabelsFont(new Font("SansSerif",Font.PLAIN,12));
	
	graph.set3DEnabled(true);
	graph.setVDepth(7);
	graph.setVerticalLabelsEnabled(true);
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.setStartDate("07012001");
	graph.setLabelsAxisStartGap(0);

	// Moves legend to the right
	graph.getLegend().setPosition(Legend.RIGHT);
	
    }

    private void createSerie() {

	double[] values={100,50,90,40,100,60,70,43,65,55};

	as=new AreaSerie(values,"area series");
	as.setColor(Color.green);

    }

    public static void main(String[] args) {
	new Main();

	// After the  Frame invisible object is instantiated the AWT thread
	// is initialized, and even after the main thread  has finished the
	// AWT thread remains active, and the JVM does  not finalize if any
	// thread is still alive. Therefore we need to  explicitily  invoke
	// the method below to end the application.
	System.exit(0);
    }

}
    
