import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;
import java.util.Vector;

/**
  * This example displays a pie chart and let user configure some   properties 
  * using a JDialog window.
  *
  * The mouse can be used to rotate pie and explode  slices.   To  rotate  pie
  * click  a slice with the left button  and drag. To  explode  slices,  click
  * click the  left button  while holding  the  Shift  key  and drag  mouse.
  *
  * The mouse can also be used to drag  pie  or  change its size. To drag pie,
  * click an  area outside  pie bounds and  drag. A double  click  outside the
  * pie bounds alternates between dragging and resizing.
  *
  * The legend  can  also be moved to  the left,  bottom  or right  positions.
  * Double  click  it and a surrounding  border   in  red will  be  displayed.
  * Then, move  mouse cursor to the left, right or  bottom sides  of the chart
  * area.  An outlined rectangle in red is displayed if mouse cursor is within
  * a valid area. Click the left mouse button to release legend in the desired
  * position.
  *
  * @author Andre de Lima Soares - alsoares@jinsight.com
  */
public class Main extends JFrame implements ActionListener  {

    PieGraph graph;
    PieSerie ps;
    PieConsole pc;

    public Main() {

	setTitle("The JetChart Library - Pie Chart Demo");
	
	// Creates graphic context. 
	graph=new PieGraph();

	// Sets the format of values displayed in tooltips.
	graph.setValueFormat("###,##0.00");

	// Enables 3D view
	graph.set3DEnabled(true);

	// Enables chart dragging
	graph.setDraggingEnabled(true);

	// Disables tooltip
	graph.getToolTip().setEnabled(false);

	// Sets gradient effect from white to blue
	graph.setGradientColors(Color.white,Color.blue);
	
	// Sets legend position
	graph.getLegend().setPosition(Legend.RIGHT);
	
	// Values of each slice
	double[] sliceValues={100,50,90,40,200,60};
	
	// Titles of each slice
	String[] titles={"Andre","Simone","Carlos","Roberto","Monica","Adriano"};
	
	// Colors of each slice.
	Color[] colors={Color.yellow,
			Color.red,Color.blue,Color.green,Color.lightGray,Color.cyan};
	
	// Creates pie series.
 	ps=new PieSerie();
	ps.setPercentageFormat("###");

	// Creates slices and sets their titles and colors.
	for (int counter=0;counter<sliceValues.length;counter++) {
	    Slice slice=new Slice(sliceValues[counter],titles[counter],colors[counter]);
	    ps.addSlice(slice);
	}

	// Adds pie serie to graphic context
	graph.addSerie(ps);

	// Explodes one slice. All slices can be exploded dinamically, just dragging them by 
	// holding the  left-button and the shift-key. A number greater than zero must be informed
	// to explode the slice.
	ps.getSlice(2).setPosition(20);

	// Sets a different font for all slice legends. 
	Vector slices=ps.getSlices();
	for (int counter=0;counter<slices.size();counter++) {
	    Slice slice=(Slice)slices.elementAt(counter);
	    slice.getSliceLegend().setFont(new Font("Arial",Font.BOLD,12));
	    slice.getSliceLegend().setArrowColor(Color.magenta);
	}

	// Sets a different font for just one slice legend
	ps.getSlice(0).getSliceLegend().setFont(new Font("Monospaced",Font.ITALIC,14));

	// Changes arrow color of one slice legend
	ps.getSlice(0).getSliceLegend().setArrowColor(Color.blue);

	// Sets some different colors to slices legends
	ps.getSlice(0).getSliceLegend().setBackground(Color.red);
	ps.getSlice(0).getSliceLegend().setForeground(Color.white);
	ps.getSlice(0).getSliceLegend().setBackground(Color.pink);
	ps.getSlice(4).getSliceLegend().setBackground(Color.orange);


	// Enables opacity of some slice legends, individually.
	ps.getSlice(0).getSliceLegend().setOpacityEnabled(true);
	ps.getSlice(2).getSliceLegend().setOpacityEnabled(true);
	ps.getSlice(4).getSliceLegend().setOpacityEnabled(true);
	
	// Changes border of some slice legends
	ps.getSlice(0).getSliceLegend().setBorder(SliceLegend.RAISED_BEVEL);
	ps.getSlice(2).getSliceLegend().setBorder(SliceLegend.SHADOWED);
	ps.getSlice(4).getSliceLegend().setBorder(SliceLegend.LOWERED_BEVEL);
	

	// Creates a Panel with a border around
	JPanel p=new JPanel();
	p.setLayout(new FlowLayout(FlowLayout.LEFT));

        Container ct=getContentPane();

	ct.add("North",p);

	// Creates a Button to show the Control Panel dialog window
	JButton b=new JButton("Control Panel");
	b.addActionListener(this);

	p.add(b);
		
	ct.add("Center",graph);

	// Adds a mouse listener
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(450,350);

	Dimension d=getToolkit().getScreenSize();
	
	// Centers frame on the screen
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);
	setVisible(true);
    }
    
    public void actionPerformed(ActionEvent evt) {

	if (pc==null) {
            // Creates a non-modal JDialog.
	    pc=new PieConsole(this,false);
            pc.setGraph(this);
        }
	pc.setVisible(true);

    }

    public static void main(String[] args) {
	new Main();
    }

}




