import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 * This demo displays a chart with three PointSeries.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener,AdjustmentListener{
    Graph graph;
    PointSerie ps1,ps2,ps3;

    JCheckBox is3D,isHorizontal;

    JScrollBar depth;

    public Main() {
	
	// A title for the frame
	setTitle("The JetChart Library - Points Chart Demo");
	
	// Values for the series
	double[] values1={550,200,250,280,300,-240,230};
	double[] values2={220,-150,60,100,130,160,180};
	double[] values3={400,70,200,600,445,220,100};

	// Creates three Point Series
        ps1=new PointSerie(values1,"Point Series 1");
        ps2=new PointSerie(values2,"Point Series 2");
        ps3=new PointSerie(values3,"Point Series 3");
		
	// Sets Point Series properties
	setPointSeriesProperties();
	
	// Labels for chart
	String[] labels={"label1","label2","label3","label4","label5",
			 "label6","label7"};

	// Creates graphic context, passing labels
	graph=new Graph(labels);

	// Sets chart optional properties
	setChartProperties();

	// Adds the three point series to the graphic context
	graph.addSerie(ps1);
	graph.addSerie(ps2);
	graph.addSerie(ps3);

        Container ct=getContentPane();

	ct.add("Center",graph);

	// Creates a top panel to layout components
	createTopPanel();

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(500,360);

	// Centers frame on the screen
	Dimension d=getToolkit().getScreenSize();
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);

	setVisible(true);

    }

    // Event handler for 3D state and chart orientation
    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==is3D) {
	    graph.set3DEnabled(is3D.isSelected());
	    depth.setEnabled(is3D.isSelected());
	}
	else if (evt.getSource()==isHorizontal) {
	    boolean hor=isHorizontal.isSelected();
	    graph.setHorizontalGraphEnabled(hor);
	    if (!hor) {
		graph.getLeftTitle().setText("Values Title");
		graph.getBottomTitle().setText("Labels Title");
	    }
	    else {
		graph.getLeftTitle().setText("Labels Title");
		graph.getBottomTitle().setText("Values Title");
	    }
	}
	graph.repaint();
    }

    // Event handler for chart depth adjustment
    public void adjustmentValueChanged(AdjustmentEvent evt) {
	if (evt.getSource()==depth) {
	    graph.setVDepth(depth.getValue());
	    graph.setHDepth(depth.getValue());
	    graph.repaint();
	}
    }
	    
	    
    // Creates top panel
    private void createTopPanel( ) {

	// Creates top panel with a border around
	JPanel topPanel=new JPanel();

	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
	
	//  Checkbox for 3D property.
	is3D=new JCheckBox("3D");
	is3D.setFont(new Font("Arial",Font.PLAIN,10));
	is3D.addItemListener(this);
	
	// Checkbox for chart orientation property
	isHorizontal=new JCheckBox("Horizontal");
	isHorizontal.setFont(new Font("Arial",Font.PLAIN,10));
	isHorizontal.addItemListener(this);

	// Scrollbar for chart depth adjustment
	depth=new JScrollBar(JScrollBar.HORIZONTAL,5,1,0,30);
        depth.setPreferredSize(new Dimension(150,depth.getPreferredSize().height));
	
	depth.setEnabled(false);
	depth.addAdjustmentListener(this);
	
	topPanel.add(is3D);
	topPanel.add(isHorizontal);
	topPanel.add(new JLabel("3D depth:"));
	topPanel.add(depth);
    
        Container ct=getContentPane();
	ct.add("North",topPanel);

    }

    private void setPointSeriesProperties() {
	// Sets color
	ps1.setColor(Color.red);
	ps2.setColor(Color.green);
	ps3.setColor(Color.pink);

	// Sets shape of each Point Serie
	ps2.setShape(PointSerie.TRIANGLE);
	ps3.setShape(PointSerie.CIRCLE);

    }

    private void setChartProperties() {
	
	// Enables tooltip
	graph.getToolTip().setEnabled(true);	

	// Sets chart title
	String[] title={"The JetChart Library","Demo with three point series"};
	graph.setTitle(title);
	
	// Sets labels title
	graph.getBottomTitle().setText("Labels Title");

	// Sets values title
	graph.getLeftTitle().setText("Values Title");

	// Applies gradient colors to graphic context
	graph.setGradientColors(Color.yellow,new Color(51,102,255));
	//graph.setGradientOrientation(graph.LEFT_TO_RIGHT);

	// Enables chart and legend dragging. A double-click over chart alternates
	// between moving chart and scale adjustment.
	graph.setDraggingEnabled(true);

	// Enables grid and sets grid color
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColor(new Color(153,153,153));

	// Sets legend orientation and position. Legend can be dinamically
	// dragged, if the Graph draggable property is set to true.
	graph.getLegend().setOrientation(Legend.HORIZONTAL);
	//graph.getLegend().setPosition(Legend.RIGHT);
	//graph.getLegend().setPosition(Legend.LEFT);

	// Sets format for values.
	graph.setValueFormat("###,###0.00");
    
	// Sets depth for vertical graph.
	graph.setVDepth(5);

	// Sets depth for horizontal graph.
	graph.setHDepth(5);
    }



    public static void main(String[] args) {
	new Main();
    }
}
